@@ -1,23 +1,19 @@
 # SPDX-FileCopyrightText: 2023 geisserml <geisserml@gmail.com>
 # SPDX-License-Identifier: Apache-2.0 OR BSD-3-Clause
 
-from enum import Enum
 from pypdfium2._cli._parsers import add_input, get_input
 
-
-class ExtractionStrategy (Enum):
-    RANGE = 0
-    BOUNDED = 1
+EXTRACT_RANGE   = "range"
+EXTRACT_BOUNDED = "bounded"
 
 
 def attach(parser):
     add_input(parser, pages=True)
     parser.add_argument(
         "--strategy",
-        type = lambda s: ExtractionStrategy[s.upper()],
-        default = ExtractionStrategy.RANGE,
+        default = EXTRACT_RANGE,
+        choices = (EXTRACT_RANGE, EXTRACT_BOUNDED),
         help = "PDFium text extraction strategy (range, bounded).",
-        # TODO think out a strategy for choices (see https://github.com/python/cpython/issues/69247)
     )
 
 
@@ -32,9 +28,9 @@ def main(args):
         textpage = page.get_textpage()
         
         # TODO let caller pass in possible range/boundary parameters
-        if args.strategy == ExtractionStrategy.RANGE:
+        if args.strategy == EXTRACT_RANGE:
             text = textpage.get_text_range()
-        elif args.strategy == ExtractionStrategy.BOUNDED:
+        elif args.strategy == EXTRACT_BOUNDED:
             text = textpage.get_text_bounded()
         else:
             assert False
