@@ -1,10 +1,12 @@
-# SPDX-FileCopyrightText: 2022 geisserml <geisserml@gmail.com>
+# SPDX-FileCopyrightText: 2023 geisserml <geisserml@gmail.com>
 # SPDX-License-Identifier: Apache-2.0 OR BSD-3-Clause
 
+from pypdfium2._helpers.unsupported import *
 from pypdfium2._helpers.misc import *
 from pypdfium2._helpers.matrix import *
-from pypdfium2._helpers.converters import *
+from pypdfium2._helpers.bitmap import *
 from pypdfium2._helpers.document import *
+from pypdfium2._helpers.attachment import *
 from pypdfium2._helpers.page import *
-from pypdfium2._helpers.pageobject import *
+from pypdfium2._helpers.pageobjects import *
 from pypdfium2._helpers.textpage import *
