@@ -12,6 +12,7 @@ from collections import namedtuple
 from concurrent.futures import ProcessPoolExecutor
 
 import pypdfium2.raw as pdfium_c
+from pypdfium2.version import V_PDFIUM_IS_V8
 from pypdfium2._helpers.misc import PdfiumError
 from pypdfium2._helpers.page import PdfPage
 from pypdfium2._helpers.pageobjects import PdfObject
@@ -63,7 +64,7 @@ class PdfDocument (AutoCloseable):
             input,
             password = None,
             autoclose = False,
-            may_init_forms = True,
+            may_init_forms = False,
         ):
         
         if isinstance(input, str):
@@ -89,17 +90,12 @@ class PdfDocument (AutoCloseable):
         
         AutoCloseable.__init__(self, self._close_impl, self._data_holder, self._data_closer)
         
+        # TODO make formtype a lazy property (it doesn't actually need a form env to retrieve)
         self.formenv = None
+        self.formtype = pdfium_c.FORMTYPE_NONE
+        self._has_forms = False
         if may_init_forms:
-            self.formtype = pdfium_c.FPDF_GetFormType(self)
-            self._has_forms = self.formtype != pdfium_c.FORMTYPE_NONE  # TODO maybe make public?
-            if self._has_forms:
-                formconfig = pdfium_c.FPDF_FORMFILLINFO(version=2)
-                raw = pdfium_c.FPDFDOC_InitFormFillEnvironment(self, formconfig)
-                self.formenv = PdfFormEnv(raw, formconfig, self)
-        else:
-            self.formtype = pdfium_c.FORMTYPE_NONE
-            self._has_forms = False
+            self._init_forms()
     
     
     @property
@@ -139,6 +135,18 @@ class PdfDocument (AutoCloseable):
         self.del_page(i)
     
     
+    def _init_forms(self):
+        self.formtype = pdfium_c.FPDF_GetFormType(self)
+        self._has_forms = self.formtype != pdfium_c.FORMTYPE_NONE  # TODO make public?
+        if self._has_forms:
+            if V_PDFIUM_IS_V8:
+                # BUG(182): would need a caller-provided form config ...
+                raise RuntimeError("pypdfium2's helpers do not support forms with V8 enabled binaries yet.")
+            formconfig = pdfium_c.FPDF_FORMFILLINFO(version=2)
+            raw = pdfium_c.FPDFDOC_InitFormFillEnvironment(self, formconfig)
+            self.formenv = PdfFormEnv(raw, formconfig, self)
+    
+    
     @classmethod
     def new(cls):
         """
